@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991-2007 Jamie Zawinski <jwz@jwz.org>
+ * Copyright (c) 1991-2009 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -14,12 +14,15 @@
 #import "DaliClockView.h"
 
 @interface AppController : NSObject
+# if MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5
+   <NSWindowDelegate>
+# endif
 {
   NSWindow *window;
   DaliClockView *view;
   BOOL titlebar_p;
   BOOL fullscreen_p;
-  int fullscreen_window_level;
+  long fullscreen_window_level;
 }
 
 - (IBAction)performFullscreen:(id)sender;
