@@ -74,8 +74,8 @@ real_window_level(long pref) {
   return (pref == 0 ? NSNormalWindowLevel        :  // normal
           pref == 1 ? NSNormalWindowLevel-1      :  // below all
           pref == 2 ? NSFloatingWindowLevel      :  // above all
-//        pref == 3 ? NSScreenSaverWindowLevel+1 :  // above saver
-          pref == 3 ? CGShieldingWindowLevel()   :  // above saver
+        pref == 3 ? NSScreenSaverWindowLevel+1 :  // above saver
+//          pref == 3 ? CGShieldingWindowLevel()   :  // above saver
           NSNormalWindowLevel);                     // unknown
 }
 
