@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991-2018 Jamie Zawinski <jwz@jwz.org>
+ * Copyright (c) 1991-2020 Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -58,23 +58,6 @@ typedef struct touch_data touch_data;
   BOOL screenLocked;
 
 # endif /* !USE_IPHONE */
-
-  GLuint textures[2];
-
-  NSTimer *clockTimer;
-  NSTimer *colorTimer;
-  NSTimer *dateTimer;
-  float autoDateInterval;
-
-  BOOL ownWindow;
-  BOOL constrainSizes;
-  BOOL usesCountdownTimer;
-  NSDate *countdownDate;
-
-  NSColor *fg;
-  NSColor *bg;
-  NSColor *initialForegroundColor;
-  NSColor *initialBackgroundColor;
 }
 
 + (void)registerDefaults:(NSUserDefaults *)defs;
@@ -107,6 +90,7 @@ typedef struct touch_data touch_data;
      dateStyle
      cycleSpeed
      usesCountdownTimer
+     usesHomeStretchTimer
      countdownDate
      initialForegroundColor
      initialBackgroundColor
@@ -118,6 +102,7 @@ typedef struct touch_data touch_data;
 @property (nonatomic) int dateStyle;
 @property (nonatomic) float cycleSpeed;
 @property (nonatomic) int usesCountdownTimer;
+@property (nonatomic) int usesHomeStretchTimer;
 @property (nonatomic, retain) NSDate *countdownDate;
 #endif /* USE_IPHONE */
 
